@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -109,8 +109,7 @@ gpk_language_populate (GpkLanguage *language, GError **error)
 		filename = g_build_filename ("/usr", "share", "xml", "iso-codes", "iso_639.xml", NULL);
 	}
 	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		if (error != NULL)
-			*error = g_error_new (1, 0, "cannot find source file : '%s'", filename);
+		g_set_error (error, 1, 0, "cannot find source file : '%s'", filename);
 		goto out;
 	}
 
