@@ -31,7 +31,6 @@
 #include <string.h>
 #include <dbus/dbus-glib.h>
 #include <packagekit-glib2/packagekit.h>
-#include <unique/unique.h>
 
 #include <gpk-common.h>
 #include <gpk-gnome.h>
@@ -288,19 +287,6 @@ gpk_prefs_auto_update_combo_setup (void)
 			  G_CALLBACK (gpk_prefs_update_combo_changed), NULL);
 }
 
-/**
- * gpk_prefs_message_received_cb
- **/
-static void
-gpk_prefs_message_received_cb (UniqueApp *app, UniqueCommand command, UniqueMessageData *message_data, guint time_ms, gpointer data)
-{
-	GtkWindow *window;
-	if (command == UNIQUE_ACTIVATE) {
-		window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_prefs"));
-		gtk_window_present (window);
-	}
-}
-
 /**
  * gpk_prefs_notify_network_state_cb:
  **/
@@ -396,7 +382,7 @@ main (int argc, char *argv[])
 	GtkWidget *main_window;
 	GtkWidget *widget;
 	PkControl *control;
-	UniqueApp *unique_app;
+	GtkApplication *application;
 	guint retval;
 	guint xid = 0;
 	GError *error = NULL;
@@ -438,14 +424,7 @@ main (int argc, char *argv[])
 	}
 
 	/* are we already activated? */
-	unique_app = unique_app_new ("org.freedesktop.PackageKit.Prefs", NULL);
-	if (unique_app_is_running (unique_app)) {
-		egg_debug ("You have another instance running. This program will now close");
-		unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL);
-		goto unique_out;
-	}
-	g_signal_connect (unique_app, "message-received",
-			  G_CALLBACK (gpk_prefs_message_received_cb), NULL);
+	application = gtk_application_new ("org.freedesktop.PackageKit.Prefs", &argc, &argv);
 
 	/* load settings */
 	settings = g_settings_new (GPK_SETTINGS_SCHEMA);
@@ -466,6 +445,7 @@ main (int argc, char *argv[])
 	}
 
 	main_window = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_prefs"));
+	gtk_application_add_window (application, GTK_WINDOW (main_window));
 
 	/* Hide window first so that the dialogue resizes itself without redrawing */
 	gtk_widget_hide (main_window);
@@ -510,8 +490,7 @@ out_build:
 	g_object_unref (control);
 	g_object_unref (builder);
 	g_object_unref (settings);
-unique_out:
-	g_object_unref (unique_app);
+	g_object_unref (application);
 
 	return 0;
 }
