@@ -16,14 +16,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
 
 #include <glib/gi18n.h>
 #include <packagekit-glib2/packagekit.h>
-#include <gconf/gconf-client.h>
 
 #include "egg-debug.h"
 
@@ -45,7 +44,7 @@ static void     gpk_task_finalize	(GObject     *object);
 struct _GpkTaskPrivate
 {
 	gpointer		 user_data;
-	GConfClient		*gconf_client;
+	GSettings		*settings;
 	GtkWindow		*parent_window;
 	GtkWindow		*current_window;
 	GtkBuilder		*builder_untrusted;
@@ -354,7 +353,8 @@ gpk_task_media_change_question (PkTask *task, guint request, PkResults *results)
 	/* TRANSLATORS: dialog body, explains to the user that they need to insert a disk to continue. The first replacement is DVD, CD etc */
 	message = g_strdup_printf (_("Additional media is required. Please insert the %s labeled '%s' to continue."), name, media_text);
 
-	priv->current_window = GTK_WINDOW (gtk_message_dialog_new (priv->parent_window, GTK_DIALOG_DESTROY_WITH_PARENT,
+	priv->current_window = GTK_WINDOW (gtk_message_dialog_new (priv->parent_window,
+								   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 								   /* TRANSLATORS: this is the window title when a new cd or dvd is required */
 								   GTK_MESSAGE_INFO, GTK_BUTTONS_CANCEL, _("A media change is required")));
 	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG(priv->current_window), "%s", message);
@@ -372,6 +372,75 @@ out:
 	g_ptr_array_unref (array);
 }
 
+#if PK_CHECK_VERSION(0,6,2)
+/**
+ * gpk_task_add_dialog_deps_section:
+ **/
+static void
+gpk_task_add_dialog_deps_section (PkTask *task, PkPackageSack *sack, PkInfoEnum info)
+{
+	PkPackageSack *sack_tmp;
+	GPtrArray *array_tmp = NULL;
+	gboolean ret;
+	GError *error = NULL;
+	guint64 size;
+	const gchar *title;
+	GpkTaskPrivate *priv = GPK_TASK(task)->priv;
+
+	sack_tmp = pk_package_sack_filter_by_info (sack, info);
+	if (pk_package_sack_get_size (sack_tmp) == 0) {
+		egg_debug ("no packages with %s", pk_info_enum_to_string (info));
+		goto out;
+	}
+
+	/* get the header */
+	switch (info) {
+	case PK_INFO_ENUM_INSTALLING:
+		/* TRANSLATORS: additional message text for the deps dialog */
+		title = _("The following software also needs to be installed");
+		break;
+	case PK_INFO_ENUM_REMOVING:
+	case PK_INFO_ENUM_OBSOLETING:
+		/* TRANSLATORS: additional message text for the deps dialog */
+		title = _("The following software also needs to be removed");
+		break;
+	case PK_INFO_ENUM_UPDATING:
+		/* TRANSLATORS: additional message text for the deps dialog */
+		title = _("The following software also needs to be updated");
+		break;
+	case PK_INFO_ENUM_REINSTALLING:
+		/* TRANSLATORS: additional message text for the deps dialog */
+		title = _("The following software also needs to be re-installed");
+		break;
+	case PK_INFO_ENUM_DOWNGRADING:
+		/* TRANSLATORS: additional message text for the deps dialog */
+		title = _("The following software also needs to be downgraded");
+		break;
+	default:
+		/* TRANSLATORS: additional message text for the deps dialog (we don't know how it's going to be processed -- eeek) */
+		title = _("The following software also needs to be processed");
+		break;
+	}
+
+	/* get the size */
+	ret = pk_package_sack_get_details (sack_tmp, NULL, &error);
+	if (!ret) {
+		egg_warning ("failed to get details about packages: %s", error->message);
+		g_error_free (error);
+	}
+	size = pk_package_sack_get_total_bytes (sack_tmp);
+
+	/* embed title */
+	array_tmp = pk_package_sack_get_array (sack_tmp);
+	gpk_dialog_embed_download_size_widget (GTK_DIALOG(priv->current_window), title, size);
+	gpk_dialog_embed_package_list_widget (GTK_DIALOG(priv->current_window), array_tmp);
+out:
+	if (array_tmp != NULL)
+		g_ptr_array_unref (array_tmp);
+	g_object_unref (sack_tmp);
+}
+#endif
+
 /**
  * gpk_task_simulate_question:
  **/
@@ -382,6 +451,7 @@ gpk_task_simulate_question (PkTask *task, guint request, PkResults *results)
 	GPtrArray *array = NULL;
 	GpkTaskPrivate *priv = GPK_TASK(task)->priv;
 	PkRoleEnum role;
+	PkPackageSack *sack = NULL;
 	guint inputs;
 	const gchar *title;
 	const gchar *message = NULL;
@@ -398,7 +468,7 @@ gpk_task_simulate_question (PkTask *task, guint request, PkResults *results)
 	/* allow skipping of deps except when we remove other packages */
 	if (role != PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES) {
 		/* have we previously said we don't want to be shown the confirmation */
-		ret = gconf_client_get_bool (priv->gconf_client, GPK_CONF_SHOW_DEPENDS, NULL);
+		ret = g_settings_get_boolean (priv->settings, GPK_SETTINGS_SHOW_DEPENDS);
 		if (!ret) {
 			egg_debug ("we've said we don't want the dep dialog");
 			pk_task_user_accepted (PK_TASK(task), priv->request);
@@ -406,51 +476,68 @@ gpk_task_simulate_question (PkTask *task, guint request, PkResults *results)
 		}
 	}
 
+	/* TRANSLATORS: title of a dependency dialog */
+	title = _("Additional confirmation required");
+
 	/* per-role messages */
 	if (role == PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES) {
-		/* TRANSLATORS: title of a dependency dialog */
-		title = _("Additional software will be installed");
 
 		/* TRANSLATORS: message text of a dependency dialog */
-		message = ngettext ("To install this package, additional software also has to be installed.",
-				    "To install these packages, additional software also has to be installed.", inputs);
+		message = ngettext ("To install this package, additional software also has to be modified.",
+				    "To install these packages, additional software also has to be modified.", inputs);
 	} else if (role == PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES) {
-		/* TRANSLATORS: title of a dependency dialog */
-		title = _("Additional software will be removed");
 
 		/* TRANSLATORS: message text of a dependency dialog */
-		message = ngettext ("To remove this package, additional software also has to be removed.",
-				    "To remove these packages, additional software also has to be removed.", inputs);
+		message = ngettext ("To remove this package, additional software also has to be modified.",
+				    "To remove these packages, additional software also has to be modified.", inputs);
 	} else if (role == PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES) {
-		/* TRANSLATORS: title of a dependency dialog */
-		title = _("Additional software will be installed");
 
 		/* TRANSLATORS: message text of a dependency dialog */
-		message = ngettext ("To update this package, additional software also has to be installed.",
-				    "To update these packages, additional software also has to be installed.", inputs);
+		message = ngettext ("To update this package, additional software also has to be modified.",
+				    "To update these packages, additional software also has to be modified.", inputs);
 	} else if (role == PK_ROLE_ENUM_SIMULATE_INSTALL_FILES) {
-		/* TRANSLATORS: title of a dependency dialog */
-		title = _("Additional software will be installed");
 
 		/* TRANSLATORS: message text of a dependency dialog */
-		message = ngettext ("To install this file, additional software also has to be installed.",
-				    "To install these file, additional software also has to be installed.", inputs);
+		message = ngettext ("To install this file, additional software also has to be modified.",
+				    "To install these file, additional software also has to be modified.", inputs);
 	} else {
-		/* TRANSLATORS: title of a dependency dialog */
-		title = _("Additional software required");
 
 		/* TRANSLATORS: message text of a dependency dialog */
-		message = _("To process this transaction, additional software is required.");
+		message = _("To process this transaction, additional software also has to be modified.");
 	}
 
-	/* get data */
-	array = pk_results_get_package_array (results);
-
-	priv->current_window = GTK_WINDOW (gtk_message_dialog_new (priv->parent_window, GTK_DIALOG_DESTROY_WITH_PARENT,
+	priv->current_window = GTK_WINDOW (gtk_message_dialog_new (priv->parent_window,
+								   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 								   GTK_MESSAGE_INFO, GTK_BUTTONS_CANCEL, "%s", title));
 	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (priv->current_window), "%s", message);
+
+#if PK_CHECK_VERSION(0,6,2)
+	/* get the details for all the packages */
+	sack = pk_results_get_package_sack (results);
+
+	gpk_task_add_dialog_deps_section (task, sack, PK_INFO_ENUM_INSTALLING);
+
+	/* TRANSLATORS: additional message text for the deps dialog */
+	gpk_task_add_dialog_deps_section (task, sack, PK_INFO_ENUM_REMOVING);
+
+	/* TRANSLATORS: additional message text for the deps dialog */
+	gpk_task_add_dialog_deps_section (task, sack, PK_INFO_ENUM_UPDATING);
+
+	/* TRANSLATORS: additional message text for the deps dialog */
+	gpk_task_add_dialog_deps_section (task, sack, PK_INFO_ENUM_OBSOLETING);
+
+	/* TRANSLATORS: additional message text for the deps dialog */
+	gpk_task_add_dialog_deps_section (task, sack, PK_INFO_ENUM_REINSTALLING);
+
+	/* TRANSLATORS: additional message text for the deps dialog */
+	gpk_task_add_dialog_deps_section (task, sack, PK_INFO_ENUM_DOWNGRADING);
+#else
+	/* get all the data */
+	array = pk_results_get_package_array (results);
 	gpk_dialog_embed_package_list_widget (GTK_DIALOG(priv->current_window), array);
-	gpk_dialog_embed_do_not_show_widget (GTK_DIALOG(priv->current_window), GPK_CONF_SHOW_DEPENDS);
+#endif
+
+	gpk_dialog_embed_do_not_show_widget (GTK_DIALOG(priv->current_window), GPK_SETTINGS_SHOW_DEPENDS);
 	/* TRANSLATORS: this is button text */
 	gtk_dialog_add_button (GTK_DIALOG(priv->current_window), _("Continue"), GTK_RESPONSE_YES);
 
@@ -460,6 +547,8 @@ gpk_task_simulate_question (PkTask *task, guint request, PkResults *results)
 	g_signal_connect (priv->current_window, "response", G_CALLBACK (gpk_task_dialog_response_cb), task);
 	gtk_widget_show_all (GTK_WIDGET(priv->current_window));
 out:
+	if (sack != NULL)
+		g_object_unref (sack);
 	if (array != NULL)
 		g_ptr_array_unref (array);
 }
@@ -613,7 +702,7 @@ gpk_task_init (GpkTask *task)
 	task->priv->request = 0;
 	task->priv->parent_window = NULL;
 	task->priv->current_window = NULL;
-	task->priv->gconf_client = gconf_client_get_default ();
+	task->priv->settings = g_settings_new (GPK_SETTINGS_SCHEMA);
 
 	/* setup dialogs ahead of time */
 	gpk_task_setup_dialog_untrusted (task);
@@ -633,7 +722,7 @@ gpk_task_finalize (GObject *object)
 	g_object_unref (task->priv->builder_untrusted);
 	g_object_unref (task->priv->builder_signature);
 	g_object_unref (task->priv->builder_eula);
-	g_object_unref (task->priv->gconf_client);
+	g_object_unref (task->priv->settings);
 
 	G_OBJECT_CLASS (gpk_task_parent_class)->finalize (object);
 }
